@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -10,7 +10,8 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/dir/buffer.c,v 1.7 2002/05/14 20:21:09 shadow Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/dir/buffer.c,v 1.13 2003/07/15 23:15:02 shadow Exp $");
 
 #include <stdlib.h>
 #include <lock.h>
@@ -53,12 +54,12 @@ struct buffer {
     afs_int32 page;
     afs_int32 accesstime;
     struct buffer *hashNext;
-    char *data;
+    void *data;
     char lockers;
     char dirty;
     char hashIndex;
     struct Lock lock;
-    } **Buffers;
+} **Buffers;
 
 char *BufferData;
 
@@ -66,21 +67,25 @@ static struct buffer *phTable[PHSIZE];	/* page hash table */
 static struct buffer *LastBuffer;
 int nbuffers;
 int timecounter;
-static int calls=0, ios=0;
+static int calls = 0, ios = 0;
 
 struct buffer *newslot();
 
-int DStat (abuffers, acalls, aios)
-    int *abuffers, *acalls, *aios;
-    {*abuffers = nbuffers;
+int
+DStat(abuffers, acalls, aios)
+     int *abuffers, *acalls, *aios;
+{
+    *abuffers = nbuffers;
     *acalls = calls;
     *aios = ios;
     return 0;
-    }
+}
 
-int DInit (abuffers)
-    int abuffers;
-    {/* Initialize the venus buffer system. */
+int
+DInit(abuffers)
+     int abuffers;
+{
+    /* Initialize the venus buffer system. */
     register int i, tsize;
     register struct buffer *tb;
     register char *tp;
@@ -88,32 +93,35 @@ int DInit (abuffers)
     Lock_Init(&afs_bufferLock);
     /* Align each element of Buffers on a doubleword boundary */
     tsize = (sizeof(struct buffer) + 7) & ~7;
-    tp = (char *) malloc(abuffers * tsize);
-    Buffers = (struct buffer **) malloc(abuffers * sizeof(struct buffer *));
-    BufferData = (char *) malloc(abuffers * BUFFER_PAGE_SIZE);
+    tp = (char *)malloc(abuffers * tsize);
+    Buffers = (struct buffer **)malloc(abuffers * sizeof(struct buffer *));
+    BufferData = (char *)malloc(abuffers * BUFFER_PAGE_SIZE);
     timecounter = 0;
     LastBuffer = (struct buffer *)tp;
     nbuffers = abuffers;
-    for(i=0;i<PHSIZE;i++) phTable[i] = 0;
-    for (i=0;i<abuffers;i++)
-        {/* Fill in each buffer with an empty indication. */
+    for (i = 0; i < PHSIZE; i++)
+	phTable[i] = 0;
+    for (i = 0; i < abuffers; i++) {
+	/* Fill in each buffer with an empty indication. */
 	tb = (struct buffer *)tp;
 	Buffers[i] = tb;
 	tp += tsize;
-        FidZero(tb->fid);
-        tb->accesstime = tb->lockers = 0;
-        tb->data = &BufferData[BUFFER_PAGE_SIZE*i];
+	FidZero(tb->fid);
+	tb->accesstime = tb->lockers = 0;
+	tb->data = &BufferData[BUFFER_PAGE_SIZE * i];
 	tb->hashIndex = 0;
-        tb->dirty = 0;
+	tb->dirty = 0;
 	Lock_Init(&tb->lock);
-        }
-    return 0;
     }
+    return 0;
+}
 
-char *DRead(fid,page)
-  register afs_int32 *fid;
-  register int page;
-{ /* Read a page from the disk. */
+void *
+DRead(fid, page)
+     register afs_int32 *fid;
+     register int page;
+{
+    /* Read a page from the disk. */
     register struct buffer *tb, *tb2, **bufhead;
 
     ObtainWriteLock(&afs_bufferLock);
@@ -123,13 +131,13 @@ char *DRead(fid,page)
 #define buf_Front(head,parent,p) {(parent)->hashNext = (p)->hashNext; (p)->hashNext= *(head);*(head)=(p);}
 
     /* this apparently-complicated-looking code is simply an example of
-     * a little bit of loop unrolling, and is a standard linked-list 
+     * a little bit of loop unrolling, and is a standard linked-list
      * traversal trick. It saves a few assignments at the the expense
      * of larger code size.  This could be simplified by better use of
      * macros.  With the use of these LRU queues, the old one-cache is
-     * probably obsolete. 
+     * probably obsolete.
      */
-    if ( tb = phTable[pHash(fid)] ) {  /* ASSMT HERE */
+    if (tb = phTable[pHash(fid)]) {	/* ASSMT HERE */
 	if (bufmatch(tb)) {
 	    ObtainWriteLock(&tb->lock);
 	    tb->lockers++;
@@ -137,39 +145,38 @@ char *DRead(fid,page)
 	    tb->accesstime = ++timecounter;
 	    ReleaseWriteLock(&tb->lock);
 	    return tb->data;
-	}
-	else {
-	  bufhead = &( phTable[pHash(fid)] );
-	  while (tb2 = tb->hashNext) {
-	    if (bufmatch(tb2)) {
-	      buf_Front(bufhead,tb,tb2);
-	      ObtainWriteLock(&tb2->lock);
-	      tb2->lockers++;
-	      ReleaseWriteLock(&afs_bufferLock);
-	      tb2->accesstime = ++timecounter;
-	      ReleaseWriteLock(&tb2->lock);
-	      return tb2->data;
+	} else {
+	    bufhead = &(phTable[pHash(fid)]);
+	    while (tb2 = tb->hashNext) {
+		if (bufmatch(tb2)) {
+		    buf_Front(bufhead, tb, tb2);
+		    ObtainWriteLock(&tb2->lock);
+		    tb2->lockers++;
+		    ReleaseWriteLock(&afs_bufferLock);
+		    tb2->accesstime = ++timecounter;
+		    ReleaseWriteLock(&tb2->lock);
+		    return tb2->data;
+		}
+		if (tb = tb2->hashNext) {	/* ASSIGNMENT HERE! */
+		    if (bufmatch(tb)) {
+			buf_Front(bufhead, tb2, tb);
+			ObtainWriteLock(&tb->lock);
+			tb->lockers++;
+			ReleaseWriteLock(&afs_bufferLock);
+			tb->accesstime = ++timecounter;
+			ReleaseWriteLock(&tb->lock);
+			return tb->data;
+		    }
+		} else
+		    break;
 	    }
-	    if (tb = tb2->hashNext) { /* ASSIGNMENT HERE! */ 
-	      if (bufmatch(tb)) {
-		buf_Front(bufhead,tb2,tb);
-		ObtainWriteLock(&tb->lock);
-		tb->lockers++;
-		ReleaseWriteLock(&afs_bufferLock);
-		tb->accesstime = ++timecounter;
-		ReleaseWriteLock(&tb->lock);
-		return tb->data;
-	      }
-	    }
-	    else break;
-	  }
 	}
-      }  
-    else tb2 = NULL;
+    } else
+	tb2 = NULL;
 
     /* can't find it */
     /* The last thing we looked at was either tb or tb2 (or nothing). That
-     * is at least the oldest buffer on one particular hash chain, so it's 
+     * is at least the oldest buffer on one particular hash chain, so it's
      * a pretty good place to start looking for the truly oldest buffer.
      */
     tb = newslot(fid, page, (tb ? tb : tb2));
@@ -177,11 +184,11 @@ char *DRead(fid,page)
     ObtainWriteLock(&tb->lock);
     tb->lockers++;
     ReleaseWriteLock(&afs_bufferLock);
-    if (ReallyRead(tb->fid,tb->page,tb->data)) {
+    if (ReallyRead(tb->fid, tb->page, tb->data)) {
 	tb->lockers--;
-        FidZap(tb->fid);	/* disaster */
+	FidZap(tb->fid);	/* disaster */
 	ReleaseWriteLock(&tb->lock);
-        return 0;
+	return 0;
     }
     /* Note that findslot sets the page field in the buffer equal to
      * what it is searching for.
@@ -190,68 +197,73 @@ char *DRead(fid,page)
     return tb->data;
 }
 
-static FixupBucket(ap)
-    register struct buffer *ap;
-    {register struct buffer **lp, *tp;
+static int
+FixupBucket(ap)
+     register struct buffer *ap;
+{
+    register struct buffer **lp, *tp;
     register int i;
+
     /* first try to get it out of its current hash bucket, in which it might not be */
     i = ap->hashIndex;
     lp = &phTable[i];
-    for(tp = *lp; tp; tp=tp->hashNext)
-	{if (tp == ap)
-	    {*lp = tp->hashNext;
+    for (tp = *lp; tp; tp = tp->hashNext) {
+	if (tp == ap) {
+	    *lp = tp->hashNext;
 	    break;
-	    }
-	lp = &tp->hashNext;
 	}
+	lp = &tp->hashNext;
+    }
     /* now figure the new hash bucket */
     i = pHash(ap->fid);
     ap->hashIndex = i;		/* remember where we are for deletion */
     ap->hashNext = phTable[i];	/* add us to the list */
-    phTable[i] = ap;            /* at the front, since it's LRU */
-    }
+    phTable[i] = ap;		/* at the front, since it's LRU */
+}
 
-struct buffer *newslot (afid, apage, lp)
-    afs_int32 *afid, apage;
-     register struct buffer *lp;   /* pointer to a fairly-old buffer */
-    {/* Find a usable buffer slot */
+struct buffer *
+newslot(afid, apage, lp)
+     afs_int32 *afid, apage;
+     register struct buffer *lp;	/* pointer to a fairly-old buffer */
+{
+    /* Find a usable buffer slot */
     register afs_int32 i;
     afs_int32 lt;
     register struct buffer **tbp;
 
     if (lp && (lp->lockers == 0)) {
-      lt = lp->accesstime;
-    }
-    else {
-      lp = 0;
-      lt = BUFFER_LONG_MAX;
+	lt = lp->accesstime;
+    } else {
+	lp = 0;
+	lt = BUFFER_LONG_MAX;
     }
 
     tbp = Buffers;
-    for (i=0;i<nbuffers;i++,tbp++) {
-      if ((*tbp)->lockers == 0) {
-	if ((*tbp)->accesstime < lt) {
-	  lp = (*tbp);
-	  lt = (*tbp)->accesstime;
+    for (i = 0; i < nbuffers; i++, tbp++) {
+	if ((*tbp)->lockers == 0) {
+	    if ((*tbp)->accesstime < lt) {
+		lp = (*tbp);
+		lt = (*tbp)->accesstime;
+	    }
 	}
-      }
     }
 
     /* There are no unlocked buffers */
     if (lp == 0) {
-      if (lt < 0)
-	Die("accesstime counter wrapped");
-      else 
-	Die ("all buffers locked");
+	if (lt < 0)
+	    Die("accesstime counter wrapped");
+	else
+	    Die("all buffers locked");
     }
 
     /* We do not need to lock the buffer here because it has no lockers
      * and the afs_bufferLock prevents other threads from zapping this
      * buffer while we are writing it out */
     if (lp->dirty) {
-        if (ReallyWrite(lp->fid,lp->page,lp->data)) Die("writing bogus buffer");
-        lp->dirty = 0;
-        }
+	if (ReallyWrite(lp->fid, lp->page, lp->data))
+	    Die("writing bogus buffer");
+	lp->dirty = 0;
+    }
 
     /* Now fill in the header. */
     FidZap(lp->fid);
@@ -262,59 +274,69 @@ struct buffer *newslot (afid, apage, lp)
     FixupBucket(lp);		/* move to the right hash bucket */
 
     return lp;
-    }
+}
 
 void
-DRelease (bp,flag)
-    register struct buffer *bp;
-    int flag;
-    {/* Release a buffer, specifying whether or not the buffer has been modified by the locker. */
+DRelease(bp, flag)
+     register struct buffer *bp;
+     int flag;
+{
+    /* Release a buffer, specifying whether or not the buffer has been modified by the locker. */
     register int index;
 
-    if (!bp) return;
-    index = (((char *)bp)-((char *)BufferData))>>LOGPS;
+    if (!bp)
+	return;
+    index = ((char *)bp - BufferData) >> LOGPS;
     bp = Buffers[index];
     ObtainWriteLock(&bp->lock);
     bp->lockers--;
-    if (flag) bp->dirty=1;
+    if (flag)
+	bp->dirty = 1;
     ReleaseWriteLock(&bp->lock);
-    }
+}
 
-DVOffset (ap)
-    register void *ap;
-    {/* Return the byte within a file represented by a buffer pointer. */
-    register struct buffer *bp;
+int
+DVOffset(ap)
+     register void *ap;
+{
+    /* Return the byte within a file represented by a buffer pointer. */
+    register struct buffer *bp = ap;
     register int index;
-    bp=ap;
-    index = (((char *)bp) - ((char *)BufferData)) >> LOGPS;
-    if (index<0 || index >= nbuffers) return -1;
-    bp = Buffers[index];
-    return BUFFER_PAGE_SIZE*bp->page+((char *)ap)-bp->data;
-    }
 
-DZap (fid)
-    register afs_int32 *fid;
-    {/* Destroy all buffers pertaining to a particular fid. */
+    index = ((char *)bp - BufferData) >> LOGPS;
+    if (index < 0 || index >= nbuffers)
+	return -1;
+    bp = Buffers[index];
+    return BUFFER_PAGE_SIZE * bp->page + (char *)ap - (char *)bp->data;
+}
+
+void
+DZap(fid)
+     register afs_int32 *fid;
+{
+    /* Destroy all buffers pertaining to a particular fid. */
     register struct buffer *tb;
     ObtainReadLock(&afs_bufferLock);
-    for(tb=phTable[pHash(fid)]; tb; tb=tb->hashNext)
-        if (FidEq(tb->fid,fid)) {
+    for (tb = phTable[pHash(fid)]; tb; tb = tb->hashNext)
+	if (FidEq(tb->fid, fid)) {
 	    ObtainWriteLock(&tb->lock);
 	    FidZap(tb->fid);
 	    tb->dirty = 0;
 	    ReleaseWriteLock(&tb->lock);
 	}
     ReleaseReadLock(&afs_bufferLock);
-    }
+}
 
-DFlushVolume (vid)
-    register afs_int32 vid;
-    {/* Flush all data and release all inode handles for a particular volume */
+int
+DFlushVolume(vid)
+     register afs_int32 vid;
+{
+    /* Flush all data and release all inode handles for a particular volume */
     register struct buffer *tb;
     register int code, rcode = 0;
     ObtainReadLock(&afs_bufferLock);
-    for(tb=phTable[vHash(vid)]; tb; tb=tb->hashNext)
-        if (FidVolEq(tb->fid,vid)) {
+    for (tb = phTable[vHash(vid)]; tb; tb = tb->hashNext)
+	if (FidVolEq(tb->fid, vid)) {
 	    ObtainWriteLock(&tb->lock);
 	    if (tb->dirty) {
 		code = ReallyWrite(tb->fid, tb->page, tb->data);
@@ -327,17 +349,19 @@ DFlushVolume (vid)
 	}
     ReleaseReadLock(&afs_bufferLock);
     return rcode;
-    }
+}
 
-DFlushEntry (fid)
-register afs_int32 *fid;
-{/* Flush pages modified by one entry. */
+int
+DFlushEntry(fid)
+     register afs_int32 *fid;
+{
+    /* Flush pages modified by one entry. */
     register struct buffer *tb;
     int code;
 
     ObtainReadLock(&afs_bufferLock);
-    for(tb = phTable[pHash(fid)]; tb; tb=tb->hashNext)
-        if (FidEq(tb->fid, fid) && tb->dirty) {
+    for (tb = phTable[pHash(fid)]; tb; tb = tb->hashNext)
+	if (FidEq(tb->fid, fid) && tb->dirty) {
 	    ObtainWriteLock(&tb->lock);
 	    if (tb->dirty) {
 		code = ReallyWrite(tb->fid, tb->page, tb->data);
@@ -354,8 +378,10 @@ register afs_int32 *fid;
     return 0;
 }
 
-DFlush ()
-{/* Flush all the modified buffers. */
+int
+DFlush()
+{
+    /* Flush all the modified buffers. */
     register int i;
     register struct buffer **tbp;
     afs_int32 code, rcode;
@@ -363,8 +389,8 @@ DFlush ()
     rcode = 0;
     tbp = Buffers;
     ObtainReadLock(&afs_bufferLock);
-    for(i=0;i<nbuffers;i++,tbp++) {
-        if ((*tbp)->dirty) {
+    for (i = 0; i < nbuffers; i++, tbp++) {
+	if ((*tbp)->dirty) {
 	    ObtainWriteLock(&(*tbp)->lock);
 	    (*tbp)->lockers++;
 	    ReleaseReadLock(&afs_bufferLock);
@@ -385,16 +411,17 @@ DFlush ()
     return rcode;
 }
 
-char *DNew (fid,page)
-  register int page;
-  register afs_int32 *fid;
+void *
+DNew(fid, page)
+     register int page;
+     register afs_int32 *fid;
 {
     /* Same as read, only do *not* even try to read the page,
      * since it probably doesn't exist.
      */
     register struct buffer *tb;
     ObtainWriteLock(&afs_bufferLock);
-    if ((tb = newslot(fid,page,0)) == 0) {
+    if ((tb = newslot(fid, page, 0)) == 0) {
 	ReleaseWriteLock(&afs_bufferLock);
 	return 0;
     }
